@@ -305,6 +305,10 @@
     cat("   n censored events=" ,x$n.censored)
     cat("\n")
     cat("   number of iterations: ", x$n.iter,"\n")
+    if (x$logNormal == 0) {
+      cat("   Number of nodes for the Gauss-Laguerre quadrature: ", x$nb.gl,"\n")
+    }
+    else {cat("   Number of nodes for the Gauss-Hermite quadrature: ", x$nb.gh,"\n")}
     
     if ((x$typeof == 1) & (x$indic.nb.intR == 1)){
       cat("   Exact number of time intervals used: 20","\n")
@@ -384,6 +388,10 @@
       cat("\n")
       cat("   n terminal events=", x$n.deaths)
       cat("\n")
+      if (x$logNormal == 0) {
+        cat("   Number of nodes for the Gauss-Laguerre quadrature: ", x$nb.gl,"\n")
+      }
+      else {cat("   Number of nodes for the Gauss-Hermite quadrature: ", x$nb.gh,"\n")}
     }
   }
   invisible()
